@@ -1,9 +1,8 @@
-#!/usr/bin/perl -W
+#!/usr/bin/perl -w
 use HTML::Menu::TreeView qw(Tree css jscript style documentRoot size clasic preload);
-use CGI::Carp qw(fatalsToBrowser);
 use CGI qw(-compile :all  -private_tempfiles);
 use strict;
-my $htpath = "../httpdocs/";
+my $htpath = documentRoot();
 my $size = defined param('size') ? param('size') : 16;
 $size = ($size== 22 or $size== 32 or $size== 48 or $size== 64 or $size== 128) ? $size : 16;
 my @tree;
@@ -34,4 +33,12 @@ size($size);
 clasic() if(defined param('clasic'));
 my $zoom =
   '<a href="./crystal.pl?style=Crystal&amp;size=16" class="treeviewLink">16</a>|<a href="./crystal.pl?style=Crystal&amp;size=22" class="treeviewLink" >22</a>|<a href="./crystal.pl?style=Crystal&amp;size=32" class="treeviewLink">32</a>|<a href="./crystal.pl?style=Crystal&amp;size=48" class="treeviewLink">48</a>|<a href="./crystal.pl?style=Crystal&amp;size=64" class="treeviewLink">64</a>|<a href="./crystal.pl?style=Crystal&amp;size=128" class="treeviewLink">128</a>';
-print header, start_html(-title => 'Columns', -script => jscript() . preload(), -style => {-code => css()}), "$zoom<br/>", Tree(\@tree), end_html;
+print header(),
+start_html(
+	-title => 'Crystal',
+	-script => jscript() . preload(),
+	-style => {-code => css()}
+),
+"$zoom<br/>",
+Tree(\@tree),
+end_html;
\ No newline at end of file
